==> XMLSchema_0.1-0.tar.gz: XMLSchema/man/processSchemaType.Rd <==
\name{processSchemaType}
\alias{processSchemaType}
\alias{processSchemaTypes}
\title{Assemble R descriptions of XML Schema types}
\description{
 These functions take an XML document or node and 
 process the details in the XML schema  to create an
 R description of the information about the types or
 type described with the schema. 
}
\usage{
processSchemaType(type, types, substitutionGroups = NULL, namespaceDefs = list())
processSchemaTypes(node, doc, namespaceDefs = xmlNamespaceDefinitions(doc), createConverters = TRUE, verbose = FALSE)
}
\arguments{
  \item{type}{an XML node describing the schema type to be processed}
  \item{types}{the collection of all XML nodes in the schema which are used to 
   to find/resolve references in \code{type} and its sub-nodes to other types within the schema.}
  \item{node}{the top-leve XML node of the schema to be processed.}
  \item{doc}{}
  \item{substitutionGroups}{XXX}
  \item{namespaceDefs}{the name space \code{prefix = URI} pairs that are in effect for the docuemnt and its nodes.
     This can be a named character vector or it might also be a list of \code{XMLNamespaceDefinition} objects
     The nodes may (re)define prefixes, but these give us the top-level pairs.
   }
  \item{createConverters}{a logical value indicating whether, 
      for each type in the schema, to 
     create the functions that convert an XML node to a corresponding
      R object.
  }
  \item{verbose}{ a logical value indicating whether to emit information about
    the element currently being processed. This is passed to \code{\link{processSchemaTypes}}.}
}
\details{

}
\value{
 \code{processSchemaType} returns an object derived from \code{SOAPType}.

 \code{processSchemaTypes} returns a list.
}
\references{
 The XML schema specification at \url{http://www.w3.org/XML/Schema}.
 A tutorial at \url{http://www.w3schools.com/Schema/default.asp}.
 Book ``The definitive XML Schema'', Priscilla Walmsley, Prentice Hall.
} 
\author{Duncan Temple Lang}
\seealso{
 \code{\link{readSchema}}
 The \code{SSOAP} package and processing a WSDL document.
}
\examples{

}
\keyword{IO}
\keyword{programming}
\keyword{data}
\concept{XML}
\concept{Meta-programming}

==> XMLSchema_0.1-6.tar.gz: XMLSchema/man/processSchemaType.Rd <==
\name{processSchemaType}
\alias{processSchemaType}
\alias{processSchemaTypes}
\title{Assemble R descriptions of XML Schema types}
\description{
 These functions take an XML document or node and 
 process the details in the XML schema  to create an
 R description of the information about the types or
 type described with the schema. 
}
\usage{
processSchemaType(type, types, substitutionGroups = NULL, namespaceDefs = list())
processSchemaTypes(node, doc, namespaceDefs = xmlNamespaceDefinitions(doc),
                    createConverters = FALSE, verbose = FALSE)
}
\arguments{
  \item{type}{an XML node describing the schema type to be processed}
  \item{types}{the collection of all XML nodes in the schema which are used to 
   to find/resolve references in \code{type} and its sub-nodes to other types within the schema.}
  \item{node}{the top-leve XML node of the schema to be processed.}
  \item{doc}{the parsed XML document in which the schema are
    defined. This is a reference to a C-level document. See the XML
    package and \code{\link[XML]{xmlParse}}.}
  \item{substitutionGroups}{XXX}
  \item{namespaceDefs}{the name space \code{prefix = URI} pairs that are in effect for the docuemnt and its nodes.
     This can be a named character vector or it might also be a list of \code{XMLNamespaceDefinition} objects
     The nodes may (re)define prefixes, but these give us the top-level pairs.
   }
  \item{createConverters}{a logical value indicating whether, 
      for each type in the schema, to 
     create the functions that convert an XML node to a corresponding
      R object.
  }
  \item{verbose}{ a logical value indicating whether to emit information about
    the element currently being processed. This is passed to \code{\link{processSchemaTypes}}.}
}
\details{

}
\value{
 \code{processSchemaType} returns an object derived from \code{SOAPType}.

 \code{processSchemaTypes} returns a list.
}
\references{
 The XML schema specification at \url{http://www.w3.org/XML/Schema}.
 A tutorial at \url{http://www.w3schools.com/Schema/default.asp}.
 Book ``The definitive XML Schema'', Priscilla Walmsley, Prentice Hall.
} 
\author{Duncan Temple Lang}
\seealso{
 \code{\link{readSchema}}
 The \code{SSOAP} package and processing a WSDL document.
}
\examples{

}
\keyword{IO}
\keyword{programming}
\keyword{data}
\concept{XML}
\concept{Meta-programming}
